@@ -1,9 +1,13 @@
-import time
+"""Setup Teardown helper classes."""
 from functools import wraps
 
 
 class ContextDecorator:
-    def __init__(self, **kwargs):
+    """Setup Teardown base class."""
+
+    def __init__(self, table: str, **kwargs):
+        """Accept table name."""
+        self.table = table
         self.__dict__.update(kwargs)
 
     def __enter__(self):
@@ -12,16 +16,18 @@ class ContextDecorator:
     def __exit__(self, typ, val, traceback):
         pass
 
-    def __call__(self, f):
-        @wraps(f)
+    def __call__(self, _func):
+        @wraps(_func)
         def wrapper(*args, **kw):
             with self:
-                return f(*args, **kw)
+                return _func(*args, **kw)
 
         return wrapper
 
 
 class SetupTeardown(ContextDecorator):
+    """Setup Teardown class."""
+
     def __enter__(self):
         self.setup(self)
         return self
